data = {
    "unixfrom": None,
    "headers": {
        "from": [
            {
                "display_name": "Keith Moore",
                "address": "moore@cs.utk.edu",
            },
        ],
        "to": [
            {
                "display_name": "Keld Jørn Simonsen",
                "address": "keld@dkuug.dk",
            },
        ],
        "cc": [
            {
                "display_name": "André Pirard",
                "address": "PIRARD@vm1.ulg.ac.be",
            },
        ],
        "subject": "If you can read this you understand the example.",
    },
    "preamble": None,
    "content": "Taken from RFC 2047, section 8.\n",
    "epilogue": None,
}

data_all = data
